package cachet.plugins.notifications;

import android.app.Notification;
import android.content.Intent;
import android.service.notification.NotificationListenerService;
import android.service.notification.StatusBarNotification;
import android.text.TextUtils;
import android.util.Log;

/**
 * Notification listening service. Intercepts notifications if permission is given to do so.
 */
public class NotificationListener extends NotificationListenerService {

    public static String NOTIFICATION_INTENT = "notification_event";
    public static String NOTIFICATION_PACKAGE_NAME = "package_name";
    public static String NOTIFICATION_MESSAGE = "message";

    @Override
    public void onNotificationPosted(StatusBarNotification event)
    {
        String msg = null;

        String packageName = event.getPackageName().toString();

        if (TextUtils.isEmpty(event.getNotification().tickerText))
            msg = getText(event);
        else
            msg = event.getNotification().tickerText.toString();

        Log.i("###", "msg = " + msg);

        Intent intent = new  Intent(NOTIFICATION_INTENT);
        intent.putExtra(NOTIFICATION_PACKAGE_NAME, packageName);
        intent.putExtra(NOTIFICATION_MESSAGE, msg);
        sendBroadcast(intent);
    }

    private String getText(StatusBarNotification event)
    {
        String result = null;
        try
        {
            Notification notification = event.getNotification();
            RemoteViews views = notification.contentView;
            Class<?> secretClass = views.getClass();

            Field outerFields[] = secretClass.getDeclaredFields();
            for (int i = 0; i < outerFields.length; i++)
            {
                if (!outerFields[i].getName().equals("mActions"))
                    continue;

                outerFields[i].setAccessible(true);

                @SuppressWarnings("unchecked")
                ArrayList<Object> actions = (ArrayList<Object>) outerFields[i].get(views);
                for (Object action : actions)
                {
                    Field innerFields[] = action.getClass().getDeclaredFields();

                    Object value = null;
                    Integer type = null;
                    for (Field field : innerFields)
                    {
                        field.setAccessible(true);
                        if (field.getName().equals("value"))
                            value = field.get(action);
                        else if (field.getName().equals("type"))
                            type = field.getInt(action);
                    }

                    if (type != null && type == 10)
                        result = value.toString();
                }
            }
        }
        catch (Exception e)
        {
            e.printStackTrace();
        }

        return result;
    }
}